GooglePlayInstantPlatform class abstract

Implementers

Constructors

GooglePlayInstantPlatform()
Constructs a GooglePlayInstantPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isInstantApp() → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showInstallPrompt() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ GooglePlayInstantPlatform
getter/setter pair